program wo_bin_ich

implicit none

!Gitterinformation des REMO-UBA-Gitters (DS 2)
integer,parameter :: dimx=109,dimy=121
real,parameter    :: pollam=-162
real,parameter    :: polphi=39.25
real,parameter    :: dlams=0.088000
real,parameter    :: dphis=0.088000
real,parameter    :: lamslu=-9.290000
real,parameter    :: phislu=-4.994000

real    :: phi,lam,rlat,rlon
integer :: ix,jy


!**********************************************************

! HIER DIE POSITION IN REALEN LONLAT-KOORDINATEN EINGEBEN:

! Station Brocken
lam=10.6657
phi=51.7655

!********************************************************
   
! hier gehts ans eingenmachte

      call rla2rls(rlon,phi,lam,polphi,pollam)
      call ph2phs(rlat,phi,lam,polphi,pollam)
      
      ix = INT(((rlon-lamslu)/dlams) + 1.5)
      jy = INT(((rlat-phislu)/dphis) + 1.5)

print*,'Die REMO-BOX ist:'
print*,'idx=', ix
print*,'idy=', jy
!********************************************

contains

!*******************************************



      subroutine ph2phs(rlat,phi,lam,polphi,pollam)

! --- Umrechnung von phi (geo. System) auf phis (rot. System)

! --- siehe Pearson, F., II (1990);
!     Map projections: theory and applications
!     CRC Press, Boca Raton (Florida), S.56-58
!     Formel: 140 S.58

! --- phi   : Breite im geographischen System (N>0)
! --- lam   : Laenge im geographischen System (E>0)
! --- polphi: Breite des rot. Nordpols im normalen geographischen System
! --- pollam: Laenge des rot. Nordpols im normalen geographischen System

      implicit none
      REAL :: phi, lam, rsinpol, rcospol, rlampol,&
              rlam, rphi, rarg,pi, pi2deg, deg2pi,rlat,pollam,polphi

      pi     = 4.*ATAN(1.)
      pi2deg = 180./pi
      deg2pi = pi/180.

      rsinpol = SIN(deg2pi*polphi)
      rcospol = COS(deg2pi*polphi)
      rlampol =     deg2pi*pollam

      IF (lam .GT. 180.) lam = lam - 360.
      rlam   = deg2pi*lam
      rphi   = deg2pi*phi

      rarg    = rcospol*COS(rphi)*COS(rlam-rlampol) + rsinpol*SIN(rphi)
      rlat = pi2deg*ASIN(rarg)

      end subroutine ph2phs
!
!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
!
      subroutine rla2rls (rlon, phi, lam, polphi, pollam)

! --- Umrechnung von lam (geo. System) auf lams (rot. System)

! --- siehe Pearson, F., II (1990);
!     Map projections: theory and applications
!     CRC Press, Boca Raton (Florida), S.56-58
!     Formel: 141 S.58
!     Anmerkung: Zaehler der Formel (141) mit -1. multiplizieren, 
!                damit der Winkel im richtigen Quadranten liegt.

! --- phi   : Breite im geographischen System (N>0)
! --- lam   : Laenge im geographischen System (E>0)
! --- polphi: Breite des rot. Nordpols im normalen geographischen System
! --- pollam: Laenge des rot. Nordpols im normalen geographischen System
      
      implicit none

      real ::  phi, lam, rsinpol, rcospol, rlampol, rlam, rphi,&
              rarg1, rarg2, pi, pi2deg, deg2pi, rlon,polphi,pollam

      pi      = 4.*ATAN(1.)
      pi2deg  = 180./pi
      deg2pi  = pi/180.

      rsinpol = SIN(deg2pi*polphi)
      rcospol = COS(deg2pi*polphi)
      rlampol =     deg2pi*pollam

      IF (lam .GT. 180.) lam = lam - 360.
      rlam    = deg2pi*lam
      rphi    = deg2pi*phi

!     rarg1  = -SIN(rlam - rlampol)*COS(rphi)
!     rarg2  = rcospol*SIN(rphi) - rsinpol*COS(rphi)*COS(rlam-rlampol) 

      rarg1  = -SIN(rlam - rlampol)
      rarg2  = rcospol*TAN(rphi) - rsinpol*COS(rlam - rlampol)


      IF (rarg2 .EQ. 0.) rarg2 = 1.E-20
      rlon= pi2deg*ATAN2(rarg1,rarg2)
 
      
      end subroutine rla2rls

!***************************************************************************



end program wo_bin_ich



